############################################################################
##
## Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
## All rights reserved.
## Contact: PySide team (contact@pyside.org)
##
## This file is part of the examples of the Python bindings for the
## QtSparql module, and it is based on a example from the C++ version
## of this module.
##
## $QT_BEGIN_LICENSE:LGPL$
## No Commercial Usage
## This file contains pre-release code and may not be distributed.
## You may use this file in accordance with the terms and conditions
## contained in the Technology Preview License Agreement accompanying
## this package.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 2.1 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL included in the
## packaging of this file.  Please review the following information to
## ensure the GNU Lesser General Public License version 2.1 requirements
## will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
##
## In addition, as a special exception, Nokia gives you certain additional
## rights.  These rights are described in the Nokia Qt LGPL Exception
## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
##
## If you have questions regarding the use of this file, please contact
## the PySide team at contact@pyside.org.
##
##
##
##
##
##
##
##
## $QT_END_LICENSE$
##
#############################################################################


from PySide.QtCore import QCoreApplication
from QtSparql import QSparqlConnection, QSparqlQuery, QSparqlResult
from QtSparql import QSparqlQueryModel, QSparql

def printPosition(q):
    i = q.pos()
    if i == QSparql.BeforeFirstRow:
        print "Position: Before first"
    elif i == QSparql.AfterLastRow:
        print "Position: After last"
    else:
        print "Position: " + str(i)

def printResultRow(rr):
    print "Result row:"
    if rr.isEmpty():
        print "Empty"
        return

    print "Column count: " + str(rr.count())
    for i in range(0,rr.count()):
        print "    " + str(i) + rr.binding(i).value()


def iterateForward(conn):
    query = QSparqlQuery(" select ?u ?p { ?u a nco:Contact ; nco:hasPhoneNumber ?pn . ?pn a nco:PhoneNumber ; nco:phoneNumber ?p }   ")

    r = conn.exec_(query)
    r.waitForFinished()

    print "---- Iterating forward ----"
    # First the query is positioned "before the first row"
    printPosition(r)
    printResultRow(r.current())

    while r.next():
        printPosition(r)
        printResultRow(r.current())
    
    # Then the query is positioned "after the last row"
    printPosition(r)
    printResultRow(r.current())

def iterateBackward(conn):

    query = QSparqlQuery(" select ?u ?p { ?u a nco:Contact ; nco:hasPhoneNumber ?pn . ?pn a nco:PhoneNumber ; nco:phoneNumber ?p }  ")

    r = conn.exec_(query)
    r.waitForFinished()

    r.last()
    r.next()

    print  "---- Iterating backwards ----"
    printPosition(r)
    printResultRow(r.current())

    while r.previous():
        printPosition(r)
        printResultRow(r.current())
    
    printPosition(r)
    printResultRow(r.current())

def insertData(conn):

    insert = QSparqlQuery(" insert { _:u a nco:Contact . _:pn a nco:PhoneNumber ; nco:phoneNumber 12345 . _:u nco:hasPhoneNumber _:pn . }  ",
                        QSparqlQuery.InsertStatement)
    r = conn.exec_(insert)
    r.waitForFinished()

def main():
  
    qapp = QCoreApplication([])

    conn = QSparqlConnection("QTRACKER")

    insertData(conn)

    iterateForward(conn)
    iterateBackward(conn)

if __name__ == "__main__":
    main()

